import redis
def parse_scan(response, **options):
	cursor, r = response
	print("光标",cursor);
	if cursor == b"0" or cursor == "0":
		return int(cursor),r;
	return cursor, r

def parse_hscan(response, **options):
	cursor, r = response
	if cursor == b"0" or cursor == "0":
		return int(cursor),r and pairs_to_dict(r) or {};
	return cursor, r and pairs_to_dict(r) or {}


def parse_zscan(response, **options):
	score_cast_func = options.get("score_cast_func", float)
	cursor, r = response
	it = iter(r)
	if cursor == b"0" or cursor == "0":
		return int(cursor),list(zip(it, map(score_cast_func, it)));
	return cursor, list(zip(it, map(score_cast_func, it)))


redis.client.AbstractRedis.RESPONSE_CALLBACKS["SCAN"] = parse_scan;
redis.client.AbstractRedis.RESPONSE_CALLBACKS["SSCAN"] = parse_scan;
redis.client.AbstractRedis.RESPONSE_CALLBACKS["HSCAN"] = parse_hscan;
redis.client.AbstractRedis.RESPONSE_CALLBACKS["ZSCAN"] = parse_zscan;



import sys
#from distutils.core import setup, Extension
from setuptools import setup,Extension,find_packages
version = sys.version_info

with open("README.md", "r") as fh:
	long_description = fh.read()

setup (name = 'kvrocks_scan',
	version = '1.2',
	description = 'kvrocks_scan',
	long_description=long_description,
	long_description_content_type="text/markdown",
	author = "lyramilk",
	packages=[''],
	install_requires = ['redis>=0.3'],
	author_email='lyramilk@qq.com',
	license='Apache License 2.0',
	url='https://github.com/lyramilk/kvrocks_scan', 
	classifiers=[
		"Intended Audience :: Developers",
		"Operating System :: OS Independent",
		"Natural Language :: Chinese (Simplified)",
		'Programming Language :: Python',
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.5',
		'Programming Language :: Python :: 2.6',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.2',
		'Programming Language :: Python :: 3.3',
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
		'Topic :: Utilities'
	],
	keywords = 'kvrocks,redis',
)


#coding:utf-8

import redis
import kvrocks_scan
#kvrocks_instance = kvrocks_scan.repair(redis.StrictRedis(host="127.0.0.1",port=6379,db=0));
kvrocks_instance = redis.StrictRedis(host="127.0.0.1",port=6379,db=0);

for k in kvrocks_instance.scan_iter("9*"):
	print(k);